"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.UniversalXMLPlugin = void 0;
const plugin_1 = require("appium/plugin");
const driver_1 = require("appium/driver");
const source_1 = require("./source");
const xpath_1 = require("./xpath");
const logger_1 = __importDefault(require("./logger"));
class UniversalXMLPlugin extends plugin_1.BasePlugin {
    async getPageSource(next, driver, sessId, addIndexPath = false) {
        const source = next ? await next() : await driver.getPageSource();
        const metadata = {};
        const { platformName } = driver.caps;
        if (platformName.toLowerCase() === 'android') {
            metadata.appPackage = driver.opts.appPackage;
        }
        const { xml, unknowns } = await (0, source_1.transformSourceXml)(source, platformName.toLowerCase(), {
            metadata,
            addIndexPath,
        });
        if (unknowns.nodes.length) {
            logger_1.default.warn(`The XML mapper found ${unknowns.nodes.length} node(s) / ` +
                `tag name(s) that it didn't know about. These should be ` +
                `reported to improve the quality of the plugin: ` +
                unknowns.nodes.join(', '));
        }
        if (unknowns.attrs.length) {
            logger_1.default.warn(`The XML mapper found ${unknowns.attrs.length} attributes ` +
                `that it didn't know about. These should be reported to ` +
                `improve the quality of the plugin: ` +
                unknowns.attrs.join(', '));
        }
        return xml;
    }
    async findElement(...args) {
        return await this._find(false, ...args);
    }
    async findElements(...args) {
        return await this._find(true, ...args);
    }
    async _find(multiple, next, driver, strategy, selector) {
        const { platformName } = driver.caps;
        if (strategy.toLowerCase() !== 'xpath' || (await driver.getCurrentContext()) !== 'NATIVE_APP') {
            return await next();
        }
        const xml = await this.getPageSource(null, driver, null, true);
        let newSelector = (0, xpath_1.transformQuery)(selector, xml, multiple);
        // if the selector was not able to be transformed, that means no elements were found that
        // matched, so do the appropriate thing based on element vs elements
        if (newSelector === null) {
            logger_1.default.warn(`Selector was not able to be translated to underlying XML. Either the requested ` +
                `element does not exist or there was an error in translation`);
            if (multiple) {
                return [];
            }
            throw new driver_1.errors.NoSuchElementError();
        }
        if (platformName.toLowerCase() === 'ios') {
            // with the XCUITest driver, the <AppiumAUT> wrapper element is present in the source but is
            // not present in the source considered by WDA, so our index path based xpath queries will
            // not work with WDA as-is. We need to remove the first path segment.
            newSelector = newSelector.replace(/^\/\*\[1\]/, '');
        }
        logger_1.default.info(`Selector was translated to: ${newSelector}`);
        // otherwise just run the transformed query!
        const finder = multiple ? 'findElements' : 'findElement';
        return await driver[finder](strategy, newSelector);
    }
}
exports.default = UniversalXMLPlugin;
exports.UniversalXMLPlugin = UniversalXMLPlugin;
//# sourceMappingURL=plugin.js.map