"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.runQuery = runQuery;
exports.transformQuery = transformQuery;
exports.getNodeAttrVal = getNodeAttrVal;
const xpath_1 = require("xpath");
const xmldom_1 = require("@xmldom/xmldom");
const lodash_1 = __importDefault(require("lodash"));
function runQuery(query, xmlStr) {
    const dom = new xmldom_1.DOMParser().parseFromString(xmlStr, xmldom_1.MIME_TYPE.XML_TEXT);
    // @ts-expect-error Misssing Node properties are not needed.
    // https://github.com/xmldom/xmldom/issues/724
    const nodes = (0, xpath_1.select)(query, dom);
    return nodes;
}
/**
 *
 * @param {string} query
 * @param {string} xmlStr
 * @param {boolean} multiple
 * @returns {string|null}
 */
function transformQuery(query, xmlStr, multiple) {
    const nodes = runQuery(query, xmlStr);
    if (!lodash_1.default.isArray(nodes)) {
        return null;
    }
    const newQueries = nodes.map((node) => {
        const indexPath = getNodeAttrVal(node, 'indexPath');
        // at this point indexPath will look like /0/0/1/1/0/1/0/2
        let newQuery = indexPath
            .substring(1) // remove leading / so we can split
            .split('/') // split into idnexes
            .map((indexStr) => {
            // map to xpath node indexes (1-based)
            const xpathIndex = parseInt(indexStr, 10) + 1;
            return `*[${xpathIndex}]`;
        })
            .join('/'); // reapply /
        // now to make this a valid xpath from the root, prepend the / we removed earlier
        return `/${newQuery}`;
    });
    let newSelector = null;
    if (newQueries.length) {
        if (multiple) {
            newSelector = newQueries.join(' | ');
        }
        else {
            newSelector = newQueries[0];
        }
    }
    return newSelector;
}
function getNodeAttrVal(node, attr) {
    const attrObjs = Object.values(node.attributes).filter((obj) => obj.name === attr);
    if (!attrObjs.length) {
        throw new Error(`Tried to retrieve a node attribute '${attr}' but the node didn't have it`);
    }
    return attrObjs[0].value;
}
//# sourceMappingURL=xpath.js.map